/**************************************************************************//**
*   @file   adi.c
*   @brief  Contains implementations of functions used by all other.
*   @author ACozma (andrei.cozma@analog.com)
*
*******************************************************************************
* Copyright 2011(c) Analog Devices, Inc.
*
* All rights reserved.
*
* Redistribution and use in source and binary forms, with or without modification,
* are permitted provided that the following conditions are met:
*  - Redistributions of source code must retain the above copyright
*    notice, this list of conditions and the following disclaimer.
*  - Redistributions in binary form must reproduce the above copyright
*    notice, this list of conditions and the following disclaimer in
*    the documentation and/or other materials provided with the
*    distribution.
*  - Neither the name of Analog Devices, Inc. nor the names of its
*    contributors may be used to endorse or promote products derived
*    from this software without specific prior written permission.
*  - The use of this software may or may not infringe the patent rights
*    of one or more patent holders.  This license does not release you
*    from the requirement that you obtain separate licenses from these
*    patent holders to use this software.
*  - Use of the software either in source or binary form, must be run
*    on or directly connected to an Analog Devices Inc. component.
*
* THIS SOFTWARE IS PROVIDED BY ANALOG DEVICES "AS IS" AND ANY EXPRESS OR IMPLIED
* WARRANTIES, INCLUDING, BUT NOT LIMITED TO, NON-INFRINGEMENT, MERCHANTABILITY
* AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
* IN NO EVENT SHALL ANALOG DEVICES BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
* SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
* INTELLECTUAL PROPERTY RIGHTS, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
* LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
* ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
* (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
* SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*
*******************************************************************************
*   SVN Revision: 710
******************************************************************************/

/*****************************************************************************/
/***************************** Include Files *********************************/
/*****************************************************************************/
#include <altera_avalon_pio_regs.h>         
#include <altera_avalon_spi.h>              
#include <unistd.h>                         
#include <system.h>                         
#include "alt_types.h"
#include <adi.h>

/*****************************************************************************/
/************************ Variables Definitions ******************************/
/*****************************************************************************/
unsigned char 	LED_Status  = 0x00; 

/**************************************************************************//**
 * @brief Set the control register to configure the PIO peripheral
 *
 * @param  iValue  - configuration value
******************************************************************************/
void SetCtrl(int iValue)
{
    IOWR_ALTERA_AVALON_PIO_DATA(CTRL_BASE, iValue);
}

/**************************************************************************//**
 * @brief Switch on one or more LEDs. The Status is kept in LED_Status
 *
 * @param aLED - the Bitmask for the LEDs to switch on
******************************************************************************/
void SetLed(int aLED)
{
	LED_Status |= aLED;

    IOWR_ALTERA_AVALON_PIO_DATA(LED_BASE, LED_Status);
}

/**************************************************************************//**
 * @brief Switch off one or more LEDs. The Status is kept in LED_Status
 *
 * @param aLED - the Bitmask for the LEDs to switch on
******************************************************************************/
void ClearLed(int aLED)
{
	LED_Status &= ~aLED;

    IOWR_ALTERA_AVALON_PIO_DATA(LED_BASE, LED_Status);
}

/**************************************************************************//**
 * @brief Change current status of the LED. The Status is kept in LED_Status
 *
 * @param aLED - the Bitmask of the LED to switch on
******************************************************************************/
void ToggleLed(int aLED)
{
	int aLedCounter;
	int aLedMask = 0x01;

	for(aLedCounter = 0; aLedCounter < 8; aLedCounter++)
	{
		if(aLED & aLedMask)
		{
			if(LED_Status & aLedMask)
            {
				LED_Status &= ~aLedMask;
            }
			else
            {
				LED_Status |= aLedMask;
            }
		}
		aLedMask <<= 1;
	}
	
    SetLed(LED_Status);
}
