/***************************************************************************//**
*   @file   cn0203.c
*   @brief  Header file of CN0203 Driver for NIOS processor.
*   @author DBogdan (dragos.bogdan@analog.com)
*
********************************************************************************
* Copyright 2012(c) Analog Devices, Inc.
*
* All rights reserved.
*
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions are met:
*  - Redistributions of source code must retain the above copyright
*    notice, this list of conditions and the following disclaimer.
*  - Redistributions in binary form must reproduce the above copyright
*    notice, this list of conditions and the following disclaimer in
*    the documentation and/or other materials provided with the
*    distribution.
*  - Neither the name of Analog Devices, Inc. nor the names of its
*    contributors may be used to endorse or promote products derived
*    from this software without specific prior written permission.
*  - The use of this software may or may not infringe the patent rights
*    of one or more patent holders.  This license does not release you
*    from the requirement that you obtain separate licenses from these
*    patent holders to use this software.
*  - Use of the software either in source or binary form, must be run
*    on or directly connected to an Analog Devices Inc. component.
*
* THIS SOFTWARE IS PROVIDED BY ANALOG DEVICES "AS IS" AND ANY EXPRESS OR IMPLIED
* WARRANTIES, INCLUDING, BUT NOT LIMITED TO, NON-INFRINGEMENT, MERCHANTABILITY
* AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
* IN NO EVENT SHALL ANALOG DEVICES BE LIABLE FOR ANY DIRECT, INDIRECT,
* INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
* LIMITED TO, INTELLECTUAL PROPERTY RIGHTS, PROCUREMENT OF SUBSTITUTE GOODS OR
* SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
* CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
* OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
* OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*
********************************************************************************
*   SVN Revision: 710
*******************************************************************************/
#ifndef _CN0203_H_
#define _CN0203_H_
#ifdef CN0203_GLOBALS
	#define CN0203_EXT extern volatile
#else
	#define CN0203_EXT volatile
#endif

/******************************************************************************/
/* Include Files                                                              */
/******************************************************************************/
#include "adi.h"
#if (USE_CN0203 == 1)

/******************************************************************************/
/* AD5620                                                                     */
/******************************************************************************/
#define AD5660_1_LOAD				(0x0 << 16) /* Load and update Norm Operation. */
#define AD5660_1_PWRDWN_1K			(0x1 << 16) /* Power-down: 1kOhm to GND. */
#define AD5660_1_PWRDWN_100K		(0x2 << 16) /* Power-down: 100kOhm to GND. */
#define AD5660_1_PWRDWN_TRISTATE	(0x3 << 16) /* Power-down: Three-state. */

/******************************************************************************/
/* AD5751                                                                     */
/******************************************************************************/
/* Input Shift Register Contents for a Write Operation  Control Register */
#define AD5750_1_CONTROL_ADDR(x)	(((x) & 0x7) << 13)	/* Part address. */
#define AD5750_1_CONTROL_WRITE		(0 << 12)			/* Write bit. */
#define AD5750_1_CONTROL_RANGE(x)	(((x) & 0xF) << 7)	/* Output range. */
#define AD5750_1_CONTROL_CLRSEL		(1 << 6)			/* Zero scale or midscale. */
#define AD5750_1_CONTROL_OUTEN		(1 << 5)			/* Output enable bit. */
#define AD5750_1_CONTROL_CLEAR		(1 << 4)			/* Software clear bit. */
#define AD5750_1_CONTROL_RSET		(1 << 3)			/* Select int current resistor.*/
#define AD5750_1_CONTROL_RESET		(1 << 2)			/* Resets the part to its power-on state. */

/* Input Shift Register Contents for a Read Operation  Status Register */
#define AD5750_1_STATUS_ADDR(x)	 	(((x) & 0x7) << 13)/* Part address. */
#define AD5750_1_STATUS_READ		(1 << 12)			/* Read bit. */
#define AD5750_1_STATUS_RANGE(x)	(((x) & 0xF) << 7)	/* Output range. */
#define AD5750_1_STATUS_CLRSEL	 	(1 << 6)			/* Zero scale or midscale. */
#define AD5750_1_STATUS_OUTEN		(1 << 5)			/* Output enable bit. */
#define AD5750_1_STATUS_RSET		(1 << 4)			/* Select int current resistor.*/
#define AD5750_1_STATUS_PEC_ERR	 	(1 << 3)			/* Interface error. */
#define AD5750_1_STATUS_OVER_TEMP	(1 << 2)			/* Temperature error. */
#define AD5750_1_STATUS_IOUT_FAULT	(1 << 1)			/* Open circuit on the IOUT pin. */
#define AD5750_1_STATUS_VOUT_FAULT	(1 << 0)			/* Short circuit on the VOUT pin. */

/******************************************************************************/
/* SPI Configuration                                                          */
/******************************************************************************/
#define AD5750_1_SYNC_PIN	(1 << 0)
#define AD5660_1_SYNC_PIN	(1 << 1)
#define CN0203_SPI			SPI_1_P0_BASE
#define CN0203_SPI_CFG		(SPI0_ena | SPI0_inv)

/******************************************************************************/
/* CN0209 GPIO                                                                */
/******************************************************************************/
#define AD5750_1_CLR_PIN	(1 << 0) // AD5750_1 Clear Pin.
#define AD5750_1_FAULT_PIN	(1 << 6) // AD5750_1 Fault Pin.

/******************************************************************************/
/* Monitored variables declarations                                           */
/******************************************************************************/
CN0203_EXT uCProbeDataUnion CN0203_data[10];	// Used to store the values for uC-Probe communication.
#endif //(USE_CN0203 == 1)

/******************************************************************************/
/* Functions Prototypes                                                       */
/******************************************************************************/
int CN0203_Init(void); 				// Initializes the communication with the device.
int CN0203_UpdateParameters(void); 	// Updates the device's monitored and controlled parameters.
#endif /* CN0203_H_ */
